LaunchDarklyConfig class

This class exposes advanced configuration options for LaunchDarkly client.

Constructors

LaunchDarklyConfig({bool allAttributesPrivate = false, Set<String> privateAttributes = const {}})
Constructor for creating a LaunchDarkly config. All parameters are optional.
const

Properties

allAttributesPrivate → bool
Specifies that user attributes (other than the key) should be hidden from LaunchDarkly. If this is set, all user attribute values will be private.
final
hashCode → int
The hash code for this object.
no setterinherited
privateAttributes → Set<String>
Marks a set of attributes private. Any users sent to LaunchDarkly with this configuration active will have attributes with these names removed. This can also be specified on a per-user basis, please refer to LaunchDarklyUser.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited