LaunchDarklyUser class

A collection of attributes that can affect flag evaluation, usually corresponding to a user of your application.

If you want to avoid sending personal information back to LaunchDarkly but keep the ability to target user segments, you can configure those attributes as private. Use private-prefixed counterparts for this purpose.

Constructors

LaunchDarklyUser({String? secondaryKey, String? privateSecondaryKey, String? ip, String? privateIp, String? country, String? privateCountry, String? avatar, String? privateAvatar, String? email, String? privateEmail, String? name, String? privateName, String? firstName, String? privateFirstName, String? lastName, String? privateLastName})
Constructor for creating a LaunchDarkly user. All parameters are optional. Use private-prefixed parameters if you want to avoid sending this paramater back to LaunchDarkly. Private parameters take precedence over public parameters. If both specified, public ones will be ignored.

Properties

avatar → String?
Sets the user's avatar.
final
country → String?
Set the country for a user.
final
email → String?
Sets the user's e-mail address.
final
firstName → String?
Sets the user's first name.
final
hashCode → int
The hash code for this object.
no setterinherited
ip → String?
Sets the IP for a user.
final
lastName → String?
Sets the user's last name.
final
name → String?
Sets the user's full name.
final
privateAttributes → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryKey → String?
Sets the secondary key for a user. This affects feature flag targeting as follows: if you have chosen to bucket users by a specific attribute, he secondary key (if set) is used to further distinguish between users who are otherwise identical according to that attribute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited